@@ -6,7 +6,7 @@ use warnings;
 
 our @ISA = qw();
 
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 
 use Carp;
 use DB_File;
@@ -22,6 +22,12 @@ Squid::Guard - Redirector for the Squid web proxy
 
     use Squid::Guard;
 
+    sub check($$) {
+        my ( $self, $req ) = @_;
+        return 'deny' if $req->host =~ /somethingnasty.com/;
+        0;
+    }
+
     my $sg = Squid::Guard->new();
 
     $sg->redir("http://proxy/cgi-bin/deny.pl";);
@@ -99,7 +105,7 @@ The following macros are supported:
 
 =back
 
-If set to the special value C<CHECKF>, then the return value of the checkf function, if true, is used directly as the redirection url
+If set to the special value C<'CHECKF'>, then the return value of the checkf function, if true, is used literally as the redirection url.
 
 =cut
 
@@ -114,7 +120,9 @@ sub redir {
 
 Sets the check callback function, which is called upn each request received.
 The check function receives as arguments the current C<Squid::Guard> object, and a L<Squid::Guard::Request> object on which the user can perform tests.
-A false return value means no redirection is to be proformed. A true return value means that the request is to be redirected to what was declared with C<redir()>.
+A false return value means no redirection is to be proformed. A true return value means that the request is to be redirected to what was declared with C<redir()> (or, in the case C<redir()> is exactly C<'CHECKF'>, to the exact return value, which in this case should be a complete url).
+
+See the examples included in the distribution.
 
 =cut
 
@@ -309,11 +317,13 @@ sub run {
 }
 
 
-=head2 Black/white-list support
+=head1 Black/white-list support
 
-Squid::Guard provides support for using precompiled black or white lists, in a way similar to what squidGuard does. These lists are organized in categories. Each category has its own path (a directory) where three files can reside. These files are named domains, urls and expressions. There's no need for all three to be there, and in most situations only the domains and urls files are used. These files list domains, urls and/or (regular) expressions which describe if a request belong to the category. You can decide, in the checkf function, to allow or to redirect a request belonging to a certain category.
-Similarly to what squidGuard does, the domains and urls files have to be compiled in .db form prior to be used. This makes it possible to run huge domains and urls lists, with acceptable performance.
+Squid::Guard provides support for using precompiled black or white lists, in a way similar to what squidGuard does. These lists are organized in categories. Each category has its own path (a directory) where three files can reside. These files are named domains, urls and expressions. There's no need for all three to be there, and in most situations only the domains and urls files are used. These files list domains, urls and/or (regular) expressions which describe if a request belong to the category. Using the checkf sub you decide wether to allow a request unchanged, or to redirect it when it belongs to a certain category you want to look for.
+
+Similarly to what squidGuard does, the domains and urls files have to be compiled in .db form prior to be used. This makes it possible to run huge domains and urls lists with acceptable performance.
 You can find precompiled lists on the net, or create your own.
+
 Beginning with version 0.13, there is EXPERIMENTAL support for the userdomains file. This file lists domains associated with users. The request will be checked against the domains only if the request has the associated identity corresponding to the user. The file is made of lines in the format C<user|domain>. At the moment, the file is entirely read in memory and no corresponding .db is generated/needed. The userdomain feature is EXPERIMENTAL and subject to change.
 Beginning with version 0.20, if the user name begins with '+', then this is taken as a UNIX group, and the domain check will be performed if the request' identity belongs to this group. If the user name begins with '!', then the name is supposed to be a Winbind group.
 
@@ -661,10 +671,14 @@ sub checkincateg($$@) {
 }
 
 
+=head1 Squid ACL support
+
+Limited support for reading in and using Squid ACLs is provided. I included this because I found that often I needed to have the same ACLs both in squid and in the redirector (for example, if you whitelist something in Squid, then likely you want it to be whitelisted in the redirector).
+This feature is still quite limited and EXPERIMENTAL. 
+
 =head2 $sg->readsquidcfg($file)
 
-Reads the given squid config file (default is /etc/squid/squid.conf).
-Currently, we look only for acl statements, and only of some basic type.
+Reads the given squid config file (default is /etc/squid/squid.conf) looking only for acl statements, and only of some basic type.
 
 =cut
 
@@ -713,12 +727,23 @@ sub readsquidcfg(;$) {
 =head2 $sg->checkinacl($req, $acl, ... )
 
 Checks if a request is in a squid.conf acl (or more).
+
 Currently only the following acl types are supported:
-src
-dstdomain
-port
-proto
-method
+
+=over
+
+=item src
+
+=item dstdomain
+
+=item port
+
+=item proto
+
+=item method
+
+=back
+
 Other types will be added when needed. Patches are welcome.
 
 =cut
@@ -797,7 +822,7 @@ sub checkinacl($$@) {
 }
 
 
-=head2 Other help subs that can be used in the checkf function
+=head1 Other help subs that can be used in the checkf function
 
 
 =head2 $sg->checkingroup($user, $group, ... )
